
# examples/download_url.pl

use strict;
use warnings;
use Data::Printer;

use MetaCPAN::Client;

my $mcpan = MetaCPAN::Client->new();

my $download_url = $mcpan->download_url('Moose');

my %output = (
    VERSION      => $download_url->version,
    STATUS       => $download_url->status,
    DATE         => $download_url->date,
    DISTRIBUTION => $download_url->distribution,
    DOWNLOAD_URL => $download_url->download_url,
);

p %output;
